@@ -568,7 +568,17 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
 
         # if no config exists automatically create the default
         ucp = ucps[0]  # you MUST have a user config path
-        self.write_user_config(ucp=ucp)
+        try:
+            self.write_user_config(ucp=ucp)
+        except FileExistsError:
+            # XXX there is a race condition here >_<
+            # where multiple seprate processes starting at
+            # the same time may try to create the empty config
+            # so even though in theory we check up there, some
+            # process will win and the rest will fail, and as
+            # a result we have to catch and ignore the error
+            pass
+
         return ucp
 
     def load(self):
@@ -932,6 +942,7 @@ class UserConfig(ConfigBase):
                 'secrets': self._secrets,
                 'authinfo': self._authinfo,
                 'mypass': self._mypass,
+                'netrc': self._netrc,
                 'ssh-config': self._ssh_config,
             }[type_]
         except KeyError as e:
@@ -969,6 +980,9 @@ class UserConfig(ConfigBase):
     def _mypass(self, blob):
         return self._get_store(stores.Mypass, blob)
 
+    def _netrc(self, blob):
+        return self._get_store(stores.Netrc, blob)
+
     def _ssh_config(self, blob):
         return self._get_store(stores.SshConfig, blob)
 
