@@ -1,5 +1,6 @@
 import os
 import stat
+import netrc
 import pathlib
 from . import exceptions as exc
 from .utils import QuietDict, log, sxpr_to_python
@@ -10,17 +11,6 @@ except ImportError as e:
     pass
 
 
-class Authinfo:
-    def __init__(self, path):
-        if isinstance(path, str):
-            path = pathlib.Path(path)
-
-        self._path = path
-
-    def __call__(self, *names):
-        raise NotImplementedError('TODO')
-
-
 class Mypass:
     def __init__(self, path):
         if isinstance(path, str):
@@ -32,6 +22,37 @@ class Mypass:
         raise NotImplementedError('TODO')
 
 
+class Netrc:
+    def __init__(self, path):
+        if isinstance(path, str):
+            path = pathlib.Path(path)
+
+        self._path = path
+
+    @property
+    def filename(self):
+        return self._path.as_posix()
+
+    @property
+    def exists(self):
+        """ Fail early and often when missing a file that is supposed to exist """
+        e = self._path.exists()
+        if not e:
+            raise FileNotFoundError(self._path)
+
+        return e
+
+    def __call__(self, *names):
+        machine, user = names
+        nc = netrc.netrc(self._path)
+        userf, act, passwd = nc.authenticators(machine)
+        if user == userf:
+            return passwd
+        else:
+            msg = 'This secret path does not exist.'
+            raise exc.SecretPathError(msg)
+
+
 class SshConfig:
     def __init__(self, path):
         if isinstance(path, str):
@@ -207,6 +228,52 @@ class Secrets:
             return current
 
 
+class Authinfo(Secrets):
+
+    def __init__(self, path):
+        if isinstance(path, str):
+            path = pathlib.Path(path)
+
+        self._path = path
+
+    @property
+    def name_id_map(self):
+        # XXX we do not support passwords with spaces right now
+        with open(self._path, 'rt') as f:
+            lines = f.readlines()
+        hrm = [l.strip().split() for l in lines if not l.startswith('default')]
+        def convk(k):
+            convd = {'machine': 'host',
+                     'login': 'user',
+                     'account': 'user',
+                     'protocol': 'port',
+                     'password': 'secret',}
+            if k in convd:
+                return convd[k]
+
+            return k
+
+        ld = [{convk(k):v for k, v in zip(l[:-1:2], l[1::2])} for l in hrm]
+        order = 'host', 'port', 'user', 'secret'
+        hier = {}
+        for d in ld:
+            if 'host' not in d or 'user' not in d or 'secret' not in d:
+                msg = f'malformed file missing host, user, or secret {self._path}'
+                raise exc.SecretError(msg)
+            nest = hier
+            for k in order[:-1]:
+                if k in d:
+                    if d[k] not in nest:
+                        if k == order[-2]:
+                            nest[d[k]] = d[order[-1]]
+                        else:
+                            nest[d[k]] = {}
+
+                    nest = nest[d[k]]
+
+        return QuietDict(hier)
+
+
 class Runtime(Secrets):
 
     exists = True
