@@ -193,6 +193,18 @@ class TestSimple(unittest.TestCase):
         except KeyError as e:
             pass
 
+    def test_netrc_1(self):
+        tv = self.auth.get('test-netrc-1')
+        assert tv == 'pass1'
+
+    def test_authinfo_1(self):
+        tv = self.auth.get('test-authinfo-1')
+        assert tv == 'pass1'
+
+    def test_authinfo_2(self):
+        tv = self.auth.get('test-authinfo-2')
+        assert tv == 'pass2'
+
 
 class TestMakeUserConfig(unittest.TestCase):
     def setUp(self):
